@@ -12,15 +12,24 @@
 
 from __future__ import print_function
 
+import logging
+
 from reno import scanner
 from reno import utils
 
+LOG = logging.getLogger(__name__)
+
 
 def list_cmd(args):
     "List notes files based on query arguments"
+    LOG.debug('starting list')
     reporoot = args.reporoot.rstrip('/') + '/'
     notesdir = utils.get_notes_dir(args)
-    notes = scanner.get_notes_by_version(reporoot, notesdir, args.branch)
+    collapse = args.collapse_pre_releases
+    notes = scanner.get_notes_by_version(
+        reporoot, notesdir, args.branch,
+        collapse_pre_releases=collapse,
+    )
     if args.version:
         versions = args.version
     else:
