@@ -11,6 +11,7 @@
 # under the License.
 
 import argparse
+import logging
 import sys
 
 from reno import create
@@ -21,6 +22,21 @@ from reno import report
 
 def main(argv=sys.argv[1:]):
     parser = argparse.ArgumentParser()
+    parser.add_argument(
+        '-v', '--verbose',
+        dest='verbosity',
+        default=logging.INFO,
+        help='produce more output',
+        action='store_const',
+        const=logging.DEBUG,
+    )
+    parser.add_argument(
+        '-q', '--quiet',
+        dest='verbosity',
+        action='store_const',
+        const=logging.WARN,
+        help='produce less output',
+    )
     parser.add_argument(
         '--rel-notes-dir', '-d',
         dest='relnotesdir',
@@ -60,6 +76,12 @@ def main(argv=sys.argv[1:]):
         default=None,
         help='the branch to scan, defaults to the current',
     )
+    do_list.add_argument(
+        '--collapse-pre-releases',
+        action='store_true',
+        default=False,
+        help='combine pre-releases with their final release',
+    )
     do_list.set_defaults(func=lister.list_cmd)
 
     do_report = subparsers.add_parser(
@@ -86,7 +108,19 @@ def main(argv=sys.argv[1:]):
         action='append',
         help='the version(s) to include, defaults to all',
     )
+    do_report.add_argument(
+        '--collapse-pre-releases',
+        action='store_true',
+        default=False,
+        help='combine pre-releases with their final release',
+    )
     do_report.set_defaults(func=report.report_cmd)
 
     args = parser.parse_args()
+
+    logging.basicConfig(
+        level=args.verbosity,
+        format='%(message)s',
+    )
+
     return args.func(args)
